## 📚 Documentation Update

### Description

Describe the documentation changes. What sections are affected, and why is this change necessary?

### Reason for Update:

Explain why these documentation changes are necessary. This could be due to new features, bug fixes, or improvements that need to be accurately reflected in the documentation.

### Changes Made

- List the changes made to the documentation.

## Checklist

- [ ] I have provided a clear description of the documentation changes.
- [ ] I have updated all affected sections of the documentation.
- [ ] I have ensured that the documentation is accurate and complete.
- [ ] I have followed the documentation guidelines of this project.
- [ ] I have made sure tests past for code example sections.

### Who can review?

List any maintainers or contributors who are best suited to review this pull request.
